#
# spec file for package libcamgm
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libcamgm
Version:        1.0.8
Release:        6.30
Summary:        CA Management Library
License:        LGPL-2.1
Group:          Development/Libraries/C and C++
Url:            https://github.com/openSUSE/libcamgm
Source0:        libcamgm-%{version}.tar.bz2
Source1:        baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  dejagnu
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  libtool
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  perl-gettext
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  ruby-devel
BuildRequires:  swig
BuildRequires:  translation-update-upstream
Requires:       ca-certificates
Requires:       openssl
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?fedora_version}
BuildRequires:  openssl-perl
BuildRequires:  perl-ExtUtils-Embed
Requires:       openssl-perl
%endif

%description
The CA Management Library provides methods for managing a certificate authority.

%package -n %{name}100
Summary:        CA Management Library
Group:          Development/Libraries/C and C++

%description -n %{name}100
The CA Management Library provides methods for managing a certificate authority.

%package devel
Summary:        CA Management Library Development Files
Group:          Development/Libraries/C and C++
Requires:       %{name}100 = %{version}
Requires:       openssl-devel
Requires:       pcre-devel

%description devel
The CA Management Library provides methods for managing
a Certificate Authority. This package includes the header files and
development documentation.

%package -n perl-camgm
Summary:        CA Management Library Perl Bindings
Group:          Development/Languages/Perl
%if 0%{?fedora_version}
Requires:       perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%else
Requires:       perl = %{perl_version}
%endif

%description -n perl-camgm
The CA Management Library provides methods for managing
a Certificate Authority.

This package provides the perl bindings to the CA Management Library.

%package -n ruby-camgm
Summary:        CA Management Library Ruby Bindings
Group:          Development/Languages/Ruby
Requires:       ruby

%description -n ruby-camgm
The CA Management Library provides methods for managing
a Certificate Authority.

This package provides the ruby bindings to the CA Management Library.

%package -n python-camgm
Summary:        CA Management Library Python Bindings
Group:          Development/Languages/Python
Requires:       python

%description -n python-camgm
The CA Management Library provides methods for managing
a Certificate Authority.

This package provides the python bindings to the CA Management Library.

%prep
%setup -q
translation-update-upstream

%build
autoreconf -fvi

export CFLAGS="%{optflags} -DNDEBUG"
export CXXFLAGS="%{optflags} -DNDEBUG"

# workaround for gettext check on x86_64
sed -i -e 's/return (int) gettext/return (long) gettext/g' configure

%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

mkdir -p %{buildroot}%{_localstatedir}/lib/
install -d -m 0700 %{buildroot}%{_localstatedir}/lib/CAM
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/CAM/.cas/
install -m 0644 %{_builddir}/%{name}-%{version}/src/openssl.cnf.tmpl %{buildroot}%{_localstatedir}/lib/CAM/
%find_lang %{name}
%fdupes %{buildroot}

%check
# required for perl test cases
export LD_LIBRARY_PATH="%{buildroot}%{_libexecdir}/"
%if 0
make check DESTDIR=%{buildroot} %{?_smp_mflags}
%else
# openssl command output differ between architectures
# openssl 1.0.1c
make check DESTDIR=%{buildroot} %{?_smp_mflags} ||:
%endif

%post -n %{name}100 -p /sbin/ldconfig

%postun -n %{name}100 -p /sbin/ldconfig

%files -n %{name}100 -f %{name}.lang
%defattr(-,root,root)
%docdir %{_defaultdocdir}/libcamgm
%dir %{_defaultdocdir}/libcamgm
%{_defaultdocdir}/libcamgm/COPYING
%{_defaultdocdir}/libcamgm/README.mkd
%attr(0700,root,root) %dir %{_localstatedir}/lib/CAM
%attr(0755,root,root) %dir %{_localstatedir}/lib/CAM/.cas
%config %{_localstatedir}/lib/CAM/openssl.cnf.tmpl
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%docdir %{_defaultdocdir}/libcamgm
%dir %{_defaultdocdir}/libcamgm
%{_defaultdocdir}/libcamgm/autodocs
%{_defaultdocdir}/libcamgm/examples
%{_libdir}/lib*.so
%{_libdir}/lib*.la
%dir %{_includedir}/ca-mgm
%{_includedir}/ca-mgm
%{_libdir}/pkgconfig/libcamgm.pc
%dir %{_datadir}/libcamgm
%dir %{_datadir}/libcamgm/typemaps/
%dir %{_datadir}/libcamgm/typemaps/perl5
%{_datadir}/libcamgm/typemaps/perl5/*.i

%files -n perl-camgm
%defattr(-,root,root)
%dir %{perl_vendorarch}/auto/CaMgm/
%{perl_vendorarch}/auto/CaMgm/*
%{perl_vendorarch}/*.pm

%files -n ruby-camgm
%defattr(-,root,root)
%{rb_vendorarchdir}/*.so

%files -n python-camgm
%defattr(-,root,root)
%{python_sitearch}/*

%changelog
* Sun Aug 30 2015 mc@suse.com
- disable testsuite
* Sat Feb  7 2015 mc@suse.de
- version 1.0.8
- replace expired certificate in the testsuite (boo#916361)
- rename configure.in into configure.ac
- update Makefiles to reduce warnings
* Sun Jan 11 2015 meissner@suse.com
- libcamgm-openssl1.0.1i.patch: remove again as 1.0.1k does more
  errors again.
* Wed Dec 10 2014 meissner@suse.com
- libcamgm-openssl1.0.1i.patch: adjust the testsuite to match
  the current openssl version (it reports less errors).
* Fri Sep 19 2014 mc@suse.de
- version 1.0.7
- Store the common server CA to /etc/pki/trust/anchors
  and run update-ca-certificates to update the trust dir
  (bnc#897441)
- upate translation files
* Mon Aug 25 2014 mc@suse.de
- version 1.0.6
- convert certificate policies to OID only (bnc#889356)
- add test for X509v3 Any Policy
- update translation files
* Thu Jun 19 2014 mc@suse.com
- replace expired certificate in the testsuite
* Thu May 15 2014 tchvatal@suse.com
- Add back support for other fedora as it is still sometimes used
* Thu May 15 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Remove conditional for other distros that we don't even build for
- Silence some of the rpmlint warnings
* Wed Apr 30 2014 mc@suse.de
- version 1.0.4
- update translations
* Sun Apr 13 2014 mc@suse.com
- version 1.0.3
- support digest sha224, sha256, sha384 and sha512
- make MD sha256 default
- add tests for new message digest algorithms
- update translation files
- remove libcamgm-1.0.2.patch - integrated upstream
* Tue Mar 18 2014 kkaempf@suse.com
- use correct type when calling C++ from Python
  add libcamgm-1.0.2.patch
* Fri Dec 20 2013 mc@suse.de
- version 1.0.2
- add new valid certificate for tests to fix the testsuite
* Sun Aug 18 2013 mc@suse.com
- version 1.0.1
- update CA certificate in the testsuite to prevent expiration
- update testcases because of the new CA certificate
* Mon Jul  1 2013 mc@suse.de
- sort dumper output to make testsuite reproducible
* Mon May 13 2013 mc@suse.com
- close pipes after exec external program is finished
* Mon Apr  8 2013 mc@suse.de
- fix build with boost 1.53
* Sun Feb 10 2013 mc@suse.com
- run testsuite only on 12.2 or higher
* Sun May 13 2012 mc@suse.com
- use LGPL-2.1 as license
- fix build with new openssl and gcc47
- build ruby bindings
- build python bindings
* Sat May 12 2012 mc@suse.com
- BuildRequire autoconf and automake
* Sat Oct  2 2010 mc@suse.de
- version 1.0.0
- initial version.
- rewrite of limal-ca-mgm without blocxx
